#pragma once
// MTDV firmware Compatibility: >=2.0
#define DLL_EXTERN_C	extern "C"
#define DLL_API __declspec(dllexport) 

#define BUFFERSIZE 1000
#define CONNECTION_PORT "80"

#define MAXSTRINGL 256

#include <string>
#include <iostream>
#include <winsock2.h>
#include <ws2tcpip.h>	//more functions and structures used to retrieve IP addresses
#include <commctrl.h>
#include <tchar.h>

#define OE_MTDV_OK 0
#define OE_MTDV_HTTPREQ_ERR_WRONGPARAM          1
#define OE_MTDV_HTTPREQ_ERR_CMDUNKNOWN          2
#define OE_MTDV_HTTPREQ_ERR_DATARANGE           3
#define HTTPREQ_ERR_DATAINTEGRITY       4
#define HTTPREQ_ERR_READONLY            5
#define HTTPREQ_ERR_DATATYPE            6
#define ERROR_WRITE						5001
#define ERROR_READ						5002
#define ERROR_PARSING					5003
#define ERROR_SOCKET					5004
#define ERROR_INVALID_IP				5005

// GenIOpt parameter types
#define GO_TYPE_U32						0
#define GO_TYPE_I32						1
#define GO_TYPE_F						2
#define GO_TYPE_BOOL					4


// GenIOptParam RW values
#define GO_RW_R							0
#define GO_RW_RW						1

#define OE_MTDV_INVALIDPOSITION			0x7FFFFFFF

struct MTDVDev
{
	char ip[MAXSTRINGL];
	char description[MAXSTRINGL];
};

struct MTDVmem
{
	int pos;
	bool valid;
};

typedef MTDVmem MTDVmemArray[4];
typedef unsigned char MTDVRawValue[4];

struct MTDVData
{
	char name[MAXSTRINGL];
	unsigned int type;
	unsigned int rw;
	char unit[MAXSTRINGL];
	MTDVRawValue dataRaw;
	MTDVRawValue dataRawMin;
	MTDVRawValue dataRawMax;

};

DLL_EXTERN_C DLL_API int restoreFactorySettings(struct MTDVDev device);
DLL_EXTERN_C DLL_API int reboot(struct MTDVDev device);

DLL_EXTERN_C DLL_API int getDevInfo(struct MTDVDev device, char *pn, char *fwver,char *macAdress, char *ip, char *subNetMask, float &temperature, float &vdd1, float &vdd2);
DLL_EXTERN_C DLL_API int getRawStatus (struct MTDVDev device, unsigned int &moving, unsigned int &error);
DLL_EXTERN_C DLL_API int getChannelsCount (struct MTDVDev device, unsigned int &channelsCount);
DLL_EXTERN_C DLL_API int getParametersCount (struct MTDVDev device, unsigned int channel,unsigned int &parametersCount);
DLL_EXTERN_C DLL_API int getChannelLog(struct MTDVDev device, unsigned int channel, char *fwver, unsigned int &homeCount, unsigned long int &stepCount);

DLL_EXTERN_C DLL_API int getData(struct MTDVDev device, unsigned int channel, unsigned int param, MTDVData &data);
DLL_EXTERN_C DLL_API int getUIntData(struct MTDVDev device, unsigned int channel, unsigned int param, char *name, char *unit, bool &writable, unsigned int &data, unsigned int &dataMin, unsigned int &dataMax);
DLL_EXTERN_C DLL_API int getIntData(struct MTDVDev device, unsigned int channel, unsigned int param, char *name, char *unit, bool &writable, int &data, int &dataMin, int &dataMax);
DLL_EXTERN_C DLL_API int getFloatData(struct MTDVDev device, unsigned int channel, unsigned int param, char *name, char *unit, bool &writable, float &data, float &dataMin, float &dataMax);
DLL_EXTERN_C DLL_API int getBoolData(struct MTDVDev device, unsigned int channel, unsigned int param, char *name, char *unit, bool &writable, bool &data);

DLL_EXTERN_C DLL_API int setUintData(struct MTDVDev device, unsigned int channel, unsigned int param, unsigned int data, unsigned int &actualData);
DLL_EXTERN_C DLL_API int setIntData(struct MTDVDev device, unsigned int channel, unsigned int param, int data, int &actualData);
DLL_EXTERN_C DLL_API int setFloatData(struct MTDVDev device, unsigned int channel, unsigned int param, float data, float &actualData);
DLL_EXTERN_C DLL_API int setBoolData(struct MTDVDev device, unsigned int channel, unsigned int param, bool data, bool &actualData);

DLL_EXTERN_C DLL_API int saveCurrentPositions(struct MTDVDev device, unsigned int memPos, unsigned int channelsMask, char* name, unsigned int &actualMemPos);
DLL_EXTERN_C DLL_API int loadPositionsAndMove(struct MTDVDev device, unsigned int memPos, unsigned int &actualMemPos, char *name);
DLL_EXTERN_C DLL_API int saveSpecificPositions(struct MTDVDev device, unsigned int mempos, char*name, int p1, int p2, int p3, int p4, unsigned int &actualMemPos);
DLL_EXTERN_C DLL_API int loadPositions(struct MTDVDev device, unsigned int mempos, char*name, unsigned int &actualMemPos, int &p1, int &p2, int &p3, int &p4 );

DLL_EXTERN_C DLL_API int setUintDataLimit(struct MTDVDev device, unsigned int channel, unsigned int param, unsigned int dataMin, unsigned int dataMax, unsigned int &actualDataMin, unsigned int &actualDataMax);
DLL_EXTERN_C DLL_API int setIntDataLimit(struct MTDVDev device, unsigned int channel, unsigned int param, int dataMin, int dataMax, int &actualDataMin, int &actualDataMax);
DLL_EXTERN_C DLL_API int setFloatDataLimit(struct MTDVDev device, unsigned int channel, unsigned int param, float dataMin, float dataMax, float &actualDataMin, float &actualDataMax);

DLL_EXTERN_C DLL_API int setChannelName(struct MTDVDev device, unsigned int channel, char *name, unsigned int &actualChannel, char* actualName);
DLL_EXTERN_C DLL_API int getChannelName(struct MTDVDev device, unsigned int channel, unsigned int &actualChannel, char* actualName);



